@@ -1,6 +1,7 @@
 import re
 from datetime import datetime
 from uuid import uuid4
+from decimal import Decimal
 
 from django.db import models
 from django.conf import settings
@@ -58,7 +59,7 @@ class Product(models.Model):
     depth = models.FloatField(null=True, blank=True)
     weight = models.FloatField(null=True, blank=True)
     price_gbp = models.DecimalField(max_digits=8, decimal_places=2,
-        default=0.0)
+        default=Decimal('0.0'))
     price_usd = models.DecimalField(max_digits=8, decimal_places=2,
         null=True, blank=True)
     price_eur = models.DecimalField(max_digits=8, decimal_places=2,
@@ -73,9 +74,9 @@ class Product(models.Model):
 
     sold_date = models.DateField(null=True, blank=True)
     cost_purchase = models.DecimalField(max_digits=8, decimal_places=2,
-        default=0.0)
+        default=Decimal('0.0'), null=True, blank=True)
     cost_work = models.DecimalField(max_digits=8, decimal_places=2,
-        default=0.0)
+        default=Decimal('0.0'), null=True, blank=True)
 
     @property
     def next(self):
